@@ -15,18 +15,21 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef RECUR_COMP_H
 #define RECUR_COMP_H
 
-#include <gtk/gtkwidget.h>
-#include <cal-util/cal-component.h>
-#include <cal-util/cal-util.h>
+#include <gtk/gtkwindow.h>
+#include <libecal/e-cal.h>
+#include <libecal/e-cal-component.h>
+#include <libecal/e-cal-util.h>
 
-gboolean recur_component_dialog (CalComponent *comp,
+gboolean recur_component_dialog (ECal *client,
+				 ECalComponent *comp,
 				 CalObjModType *mod,
-				 GtkWindow *parent);
+				 GtkWindow *parent,
+				 gboolean delegated);
 
 #endif
