@@ -756,7 +756,7 @@ emp_standard_menu_factory(EPopup *emp, void *data)
                 gchar *cp;
 
                 /* GNOME-VFS expects lowercase MIME types. */
-                for (cp = mime_type; *cp != NULL; cp++)
+                for (cp = mime_type; *cp != 0; cp++)
                         *cp = g_ascii_tolower (*cp);
 
 		apps = gnome_vfs_mime_get_all_applications(mime_type);
