@@ -206,7 +206,7 @@ store_info_unref(struct _store_info *si)
 	g_free(si);
 }
 
-static void
+static gboolean
 mc_add_store_done(CamelStore *store, CamelFolderInfo *info, void *data)
 {
 	struct _store_info *si = data;
@@ -223,6 +223,8 @@ mc_add_store_done(CamelStore *store, CamelFolderInfo *info, void *data)
 	}
 
 	store_info_unref(si);
+
+	return TRUE;
 }
 
 /* Utility functions.  */
@@ -368,6 +370,7 @@ static void
 mc_startup(MailComponent *mc)
 {
 	static int started = 0;
+	GConfClient *gconf;
 
 	if (started)
 		return;
@@ -375,7 +378,11 @@ mc_startup(MailComponent *mc)
 
 	mc_setup_local_store(mc);
 	load_accounts(mc, mail_config_get_accounts());
-	vfolder_load_storage();
+
+	gconf = mail_config_get_gconf_client();
+
+	if (gconf_client_get_bool (gconf, "/apps/evolution/mail/display/enable_vfolders", NULL))
+		vfolder_load_storage();
 }
 
 static void
@@ -484,6 +491,7 @@ impl_finalize (GObject *object)
 
 	g_free (priv->context_path);
 	g_mutex_free(priv->lock);
+	g_object_unref (priv->model);
 	g_object_unref (priv->logger);
 	g_free (priv);
 
@@ -826,11 +834,14 @@ impl_quit(PortableServer_Servant servant, CORBA_Environment *ev)
 	mail_config_prune_proxies ();
 	switch (mc->priv->quit_state) {
 	case MC_QUIT_START: {
+		extern int camel_application_is_exiting;
 		int now = time(NULL)/60/60/24, days;
 		gboolean empty_junk;
 
 		GConfClient *gconf = mail_config_get_gconf_client();
 
+		camel_application_is_exiting = TRUE;
+
 		mail_vfolder_shutdown();
 
 		mc->priv->quit_expunge = gconf_client_get_bool(gconf, "/apps/evolution/mail/trash/empty_on_exit", NULL)
@@ -1010,7 +1021,7 @@ impl_handleURI (PortableServer_Servant servant, const char *uri, CORBA_Environme
 		if (camel_url_get_param(url, "uid") != NULL) {
 			char *curi = em_uri_to_camel(uri);
 
-			mail_get_folder(curi, 0, handleuri_got_folder, url, mail_thread_new);
+			mail_get_folder(curi, 0, handleuri_got_folder, url, mail_msg_unordered_push);
 			g_free(curi);
 		} else {
 			g_warning("email uri's must include a uid parameter");
@@ -1619,7 +1630,7 @@ mail_component_show_logger (gpointer top)
 	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_transient_for ((GtkWindow *) window, (GtkWindow *) gtk_widget_get_toplevel ((GtkWidget *) top));
 	gtk_container_set_border_width ((GtkContainer *) window, 6);
-
+	gtk_window_set_default_size ((GtkWindow *)window, 500, 400);
 	gtk_window_set_title ((GtkWindow *) window, _("Debug Logs"));
 	vbox = gtk_vbox_new (FALSE, 6);
 	hbox = gtk_hbox_new (FALSE, 6);	
