@@ -1,14 +1,14 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
-/* 
- * Authors: 
+/*
+ * Authors:
  *  Peter Williams <peterw@ximian.com>
  *  Michael Zucchi <notzed@ximian.com>
  *
  * Copyright 2000, 2001 Ximian, Inc. (www.ximian.com)
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -30,13 +30,14 @@ extern "C" {
 #pragma }
 #endif /* __cplusplus */
 
+#include "mail-mt.h"
+
 #include "camel/camel-store.h"
 #include "camel/camel-folder.h"
 #include "camel/camel-filter-driver.h"
 #include "camel/camel-mime-message.h"
 #include "camel/camel-operation.h"
 
-#include "libedataserver/e-msgport.h"
 #include "libedataserver/e-account.h"
 
 void mail_append_mail (CamelFolder *folder, CamelMimeMessage *message, CamelMessageInfo *info,
@@ -55,12 +56,12 @@ void mail_transfer_messages (CamelFolder *source, GPtrArray *uids,
 void mail_get_message (CamelFolder *folder, const char *uid,
 		       void (*done) (CamelFolder *folder, const char *uid, CamelMimeMessage *msg, void *data),
 		       void *data,
-		       EThread *thread);
+		       MailMsgDispatchFunc dispatch);
 
 void
 mail_get_messagex(CamelFolder *folder, const char *uid,
 		  void (*done) (CamelFolder *folder, const char *uid, CamelMimeMessage *msg, void *data, CamelException *),
-		  void *data, EThread *thread);
+		  void *data, MailMsgDispatchFunc dispatch);
 
 /* get several messages */
 void mail_get_messages (CamelFolder *folder, GPtrArray *uids,
@@ -70,7 +71,7 @@ void mail_get_messages (CamelFolder *folder, GPtrArray *uids,
 /* same for a folder */
 int mail_get_folder (const char *uri, guint32 flags,
 		     void (*done) (char *uri, CamelFolder *folder, void *data), void *data,
-		     EThread *thread);
+		     MailMsgDispatchFunc dispatch);
 
 /* and for a store */
 int mail_get_store (const char *uri, CamelOperation *op,
@@ -102,7 +103,7 @@ void mail_empty_trash (EAccount *account,
 
 /* get folder info asynchronously */
 int mail_get_folderinfo (CamelStore *store, CamelOperation *op,
-			 void (*done)(CamelStore *store, CamelFolderInfo *info, void *data),
+			 gboolean (*done)(CamelStore *store, CamelFolderInfo *info, void *data),
 			 void *data);
 
 /* remove an existing folder */
