@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
  */
 
@@ -33,13 +33,15 @@
 #include <calendar/gui/e-cal-config.h>
 #include <libedataserver/e-source.h>
 #include <libedataserver/e-url.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 #include <string.h>
 
 GtkWidget *e_calendar_http_url (EPlugin *epl, EConfigHookItemFactoryData *data);
 GtkWidget *e_calendar_http_refresh (EPlugin *epl, EConfigHookItemFactoryData *data);
 gboolean   e_calendar_http_check (EPlugin *epl, EConfigHookPageCheckData *data);
 GtkWidget * e_calendar_http_secure (EPlugin *epl, EConfigHookItemFactoryData *data);
+GtkWidget *e_calendar_http_auth (EPlugin *epl, EConfigHookItemFactoryData *data);
+
 static gchar *
 print_uri_noproto (EUri *uri)
 {
@@ -88,7 +90,7 @@ url_changed (GtkEntry *entry, ESource *source)
 
 		secure_checkbox = g_object_get_data (G_OBJECT (gtk_widget_get_parent (GTK_WIDGET (entry))),
 		                                     "secure_checkbox");
-                 
+
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (secure_checkbox), TRUE);
 	}
 
@@ -225,12 +227,12 @@ option_changed (GtkOptionMenu *option, ECalConfigTargetSource *t)
 	g_free (refresh_str);
 }
 
-static void 
+static void
 secure_setting_changed (GtkWidget *widget, ESource *source)
 {
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)))
 		e_source_set_property (source, "use_ssl", "1");
-	else 
+	else
 		e_source_set_property (source, "use_ssl", "0");
 }
 
@@ -340,7 +342,7 @@ e_calendar_http_secure (EPlugin *epl, EConfigHookItemFactoryData *data)
 
 	secure_prop = e_source_get_property (t->source, "use_ssl");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (secure_setting), (secure_prop && g_str_equal (secure_prop, "1"))  ? TRUE : FALSE);
-  
+
 	g_signal_connect (secure_setting, "toggled", G_CALLBACK (secure_setting_changed), t->source);
 
 	gtk_widget_show (secure_setting);
@@ -348,10 +350,77 @@ e_calendar_http_secure (EPlugin *epl, EConfigHookItemFactoryData *data)
 
 	/* Store pointer to secure checkbox so we can retrieve it in url_changed() */
 	g_object_set_data (G_OBJECT (parent), "secure_checkbox", (gpointer)secure_setting);
-	
+
 	return secure_setting;
 }
 
+static void
+username_changed (GtkEntry *entry, ESource *source)
+{
+	const gchar *username;
+
+	username = gtk_entry_get_text (GTK_ENTRY (entry));
+
+	if (username && username[0]) {
+		e_source_set_property (source, "auth", "1");
+		e_source_set_property (source, "username", username);
+	} else {
+		e_source_set_property (source, "auth", NULL);
+		e_source_set_property (source, "username", NULL);
+	}
+}
+
+GtkWidget *
+e_calendar_http_auth (EPlugin *epl, EConfigHookItemFactoryData *data)
+{
+	static GtkWidget *label;
+	GtkWidget *entry, *parent;
+	int row;
+	ECalConfigTargetSource *t = (ECalConfigTargetSource *) data->target;
+	EUri *uri;
+	char *uri_text;
+	const char *username;
+	static GtkWidget *hidden = NULL;
+
+	if (!hidden)
+		hidden = gtk_label_new ("");
+
+	if (data->old)
+		gtk_widget_destroy (label);
+
+	uri_text = e_source_get_uri (t->source);
+	uri = e_uri_new (uri_text);
+	g_free (uri_text);
+	if ((strcmp (uri->protocol, "http") &&
+	     strcmp (uri->protocol, "https") &&
+	     strcmp (uri->protocol, "webcal"))) {
+		e_uri_free (uri);
+		return hidden;
+	}
+	e_uri_free (uri);
+
+	parent = data->parent;
+
+	row = ((GtkTable*)parent)->nrows;
+
+	label = gtk_label_new_with_mnemonic (_("Userna_me:"));
+	gtk_widget_show (label);
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);
+	gtk_table_attach (GTK_TABLE (parent), label, 0, 1, row, row+1, GTK_FILL, GTK_SHRINK, 0, 0);
+
+	username = e_source_get_property (t->source, "username");
+
+	entry = gtk_entry_new ();
+	gtk_widget_show (entry);
+	gtk_entry_set_text (GTK_ENTRY (entry), username ? username : "");
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), entry);
+	g_signal_connect (G_OBJECT (entry), "changed", G_CALLBACK (username_changed), t->source);
+
+	gtk_table_attach (GTK_TABLE (parent), entry, 1, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+
+	return entry;
+}
+
 gboolean
 e_calendar_http_check (EPlugin *epl, EConfigHookPageCheckData *data)
 {
