@@ -45,6 +45,7 @@
 #include <gtk/gtknotebook.h>
 #include <gtk/gtktooltips.h>
 #include <gtk/gtkvbox.h>
+#include <gtk/gtkiconfactory.h>
 
 #include <bonobo/bonobo-exception.h>
 #include <bonobo/bonobo-object.h>
@@ -389,6 +390,7 @@ update_offline_toggle_status (EShellWindow *window)
 		flags = ES_MENU_SHELL_OFFLINE;
 		break;
 	case E_SHELL_LINE_STATUS_OFFLINE:
+	case E_SHELL_LINE_STATUS_FORCED_OFFLINE:
 		icon        = OFFLINE_ICON;
 		sensitive   = TRUE;
 		tooltip     = _("Evolution is currently offline. "
@@ -414,7 +416,8 @@ update_offline_toggle_status (EShellWindow *window)
 static void
 update_send_receive_sensitivity (EShellWindow *window)
 {
-	if (e_shell_get_line_status (window->priv->shell.eshell) == E_SHELL_LINE_STATUS_OFFLINE)
+	if (e_shell_get_line_status (window->priv->shell.eshell) == E_SHELL_LINE_STATUS_OFFLINE || 
+		e_shell_get_line_status (window->priv->shell.eshell) == E_SHELL_LINE_STATUS_FORCED_OFFLINE)
 		bonobo_ui_component_set_prop (window->priv->ui_component,
 					      "/commands/SendReceive",
 					      "sensitive", "0", NULL);
@@ -484,6 +487,7 @@ offline_toggle_clicked_callback (GtkButton *button,
 		e_shell_go_offline (priv->shell.eshell, window, GNOME_Evolution_USER_OFFLINE);
 		break;
 	case E_SHELL_LINE_STATUS_OFFLINE:
+	case E_SHELL_LINE_STATUS_FORCED_OFFLINE:
 		e_shell_go_online (priv->shell.eshell, window, GNOME_Evolution_USER_ONLINE);
 		break;
 	default:
@@ -603,10 +607,16 @@ setup_status_bar (EShellWindow *window)
 	EShellWindowPrivate *priv;
 	BonoboUIEngine *ui_engine;
 	GConfClient *gconf_client;
+	gint height;
 
 	priv = window->priv;
 
 	priv->status_bar = gtk_hbox_new (FALSE, 2);
+
+	/* Make the status bar as large as the task bar. */
+	gtk_icon_size_lookup (GTK_ICON_SIZE_MENU, NULL, &height);
+	gtk_widget_set_size_request (GTK_WIDGET (priv->status_bar), -1, height * 2);
+
 	gconf_client = gconf_client_get_default ();
 	if(gconf_client_get_bool (gconf_client,"/apps/evolution/shell/view_defaults/statusbar_visible",NULL))
 		gtk_widget_show (priv->status_bar);
