@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  * Author: Ettore Perazzoli
  * 	   Srinivasa Ragavan
@@ -48,18 +48,17 @@ extern "C" {
 
 typedef struct _EAttachmentBar EAttachmentBar;
 typedef struct _EAttachmentBarClass EAttachmentBarClass;
-typedef struct _EAttachmentBarPrivate EAttachmentBarPrivate;
 
 struct _EAttachmentBar {
 	GnomeIconList parent;
 	gboolean expand;
 
-	EAttachmentBarPrivate *priv;
+	struct _EAttachmentBarPrivate *priv;
 };
 
 struct _EAttachmentBarClass {
 	GnomeIconListClass parent_class;
-	
+
 	void (* changed) (EAttachmentBar *bar);
 };
 
@@ -68,12 +67,12 @@ GtkType e_attachment_bar_get_type (void);
 
 GtkWidget *e_attachment_bar_new (GtkAdjustment *adj);
 void e_attachment_bar_to_multipart (EAttachmentBar *bar, CamelMultipart *multipart,
-						 const char *default_charset);
+				    const char *default_charset);
 guint e_attachment_bar_get_num_attachments (EAttachmentBar *bar);
-void e_attachment_bar_attach (EAttachmentBar *bar, const char *file_name, char *disposition);
+void e_attachment_bar_attach (EAttachmentBar *bar, const char *file_name, const char *disposition);
 void e_attachment_bar_attach_mime_part (EAttachmentBar *bar, CamelMimePart *part);
 int e_attachment_bar_get_download_count (EAttachmentBar *bar);
-void e_attachment_bar_attach_remote_file (EAttachmentBar *bar,const gchar *url);
+void e_attachment_bar_attach_remote_file (EAttachmentBar *bar, const char *url, const char *disposition);
 GSList *e_attachment_bar_get_attachment (EAttachmentBar *bar, int id);
 void e_attachment_bar_add_attachment (EAttachmentBar *bar, EAttachment *attachment);
 void e_attachment_bar_edit_selected (EAttachmentBar *bar);
@@ -83,6 +82,9 @@ GSList *e_attachment_bar_get_parts (EAttachmentBar *bar);
 GSList *e_attachment_bar_get_selected (EAttachmentBar *bar);
 void e_attachment_bar_set_width(EAttachmentBar *bar, int bar_width);
 GSList * e_attachment_bar_get_all_attachments (EAttachmentBar *bar);
+void e_attachment_bar_create_attachment_cache (EAttachment *attachment);
+void e_attachment_bar_add_attachment_silent (EAttachmentBar *bar, EAttachment *attachment);
+void e_attachment_bar_refresh (EAttachmentBar *bar);
 
 #ifdef __cplusplus
 }
