@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  * Author: Ettore Perazzoli <ettore@ximian.com>
  */
@@ -72,6 +72,12 @@ void       e_combo_button_set_label  (EComboButton *combo_button,
 				      const char   *label);
 void       e_combo_button_set_menu   (EComboButton *combo_button,
 				      GtkMenu      *menu);
+void       e_combo_button_pack_vbox  (EComboButton *combo_button);
+void       e_combo_button_pack_hbox  (EComboButton *combo_button);
+
+GtkWidget *e_combo_button_get_label  (EComboButton *combo_button);
+
+gboolean   e_combo_button_popup_menu (EComboButton *combo_button);
 
 #ifdef __cplusplus
 }
